@@ -173,7 +173,7 @@ class Tcprobe(MediaInfo):
         self.log.setLevel(pref['logLevel'])
 
         self.process = StdIOProcess("tcprobe", ['-i', self.filename.encode(pref['systemEncoding'])],
-                                    scriptProxy, pref['scriptPath'])
+                                    scriptProxy)
         
 
 
