@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 100 $
+# Revision: $Rev: 102 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -35,7 +35,7 @@ from pprint import pformat
 CONFIG_TEXT = """\
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 100 $
+# Revision: $Rev: 102 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -111,14 +111,6 @@ logLevel = %(logLevel)s
 defaultPath = %(defaultPath)s
 
 
-# scriptPath defines the location of the auxilary scripts which
-# lmc uses to gather information on movie titles from the internet.
-# Default value is the \"scripts\" subdirectory, relative to lmc's
-# source directory.
-
-scriptPath = %(scriptPath)s
-
-
 # browserPath is the path to the executable of your prefered internet
 # browser. This is the program executed to load external HTML pages.
 # The default is '/usr/bin/mozilla'.
@@ -280,7 +272,9 @@ imageFormat = %(imageFormat)s
 # somewhere in the filename. This is replaced with the record ID as the
 # picture is saved.
 # If the path does not exist, it will be created recursively. You can
-# specify an absolute path here.
+# specify an absolute path here. If you specify a relative path name
+# the file will be linked as absolute file, anyways. Backslash-escape
+# the first character in filenamePrefix to enforce relative paths.
 # The default value will put the files in the directory \"pictures\"
 # from the current working directory and let the record ID be zero-prefixed
 # to four decimal places.
@@ -379,7 +373,6 @@ class _Settings0(dict):
                      },
 
         'defaultPath': os.environ['PWD'],
-        'scriptPath': 'scripts/',
         'browserPath': '/usr/bin/mozilla',
 
         'defaultHistory': {'subtitles'       : ('English', 'German'),
@@ -430,7 +423,7 @@ class _Settings0(dict):
         
         'recordStoreOrderRandom': False,
 
-        'deepcopyOnCopy': True,
+        'deepcopyOnCopy': False,
         
         'mediaInfo': None,
         'autoMountPoint': None,
@@ -490,7 +483,7 @@ class _Settings0(dict):
                                      "import MediaInfo"])}
 
         # general fields
-        for key in ['logLevel', 'defaultPath', 'scriptPath', 'browserPath',
+        for key in ['logLevel', 'defaultPath', 'browserPath',
                     'proxy', 'systemEncoding', 'recordStoreOrderRandom',
                     'embeddedImage', 'imageFormat', 'filenamePrefix', 'sortColumn',
                     'zeroPrefix_patch', 'scripts', 'defaultScript', 'autoMountPoint',
@@ -604,7 +597,7 @@ class _Pref(dict):
         """updates the own contents, given a template"""
         self.clear()
         # update simple values
-        for key in ['defaultPath', 'scriptPath', 'browserPath', 'proxy',
+        for key in ['defaultPath', 'browserPath', 'proxy',
                     'systemEncoding', 'recordStoreOrderRandom', 'mediaInfo',
                     'embeddedImage', 'imageFormat', 'filenamePrefix',
                     'sortColumn', 'zeroPrefix_patch', 'scripts',
