@@ -1,7 +1,7 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 101 $
+# Revision: $Rev: 104 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -42,6 +42,8 @@ from copy import deepcopy
 import Settings
 import MediaInfo
 
+from defaults import scriptdir
+
 from LMCWidgetBase import LMCWidgetBase
 from AMCFile33 import AMCFile33, AMCRecord33
 from RecordList import RecordList
@@ -62,7 +64,7 @@ log.addHandler(hdlr)
 log.setLevel(logging.DEBUG)             # default log level
 
 # output program text-logo
-log.info("lmc.py - LMC Movie Catalogue  $Rev: 101 $ (c) by Uwe Mayer")
+log.info("lmc.py - LMC Movie Catalogue  $Rev: 104 $ (c) by Uwe Mayer")
 
 # load settings
 settings = Settings.Settings()
@@ -104,7 +106,7 @@ fileFilterList = filter(lambda a: a != "", map(lambda a: a[1], fileFormats))
 
 
 #-- utility functions ----------------------------------------------------------
-defaultCaption = "LMC Movie Catalogue"
+defaultCaption = "LMC Movie Catalogue ($Rev: 104 $) "
 filenameCaption = lambda a: defaultCaption+" - %s"%basename(a)
 
 
@@ -528,7 +530,7 @@ class LMCMain(LMCWidgetBase):
             self.log.info("Getting title list from %s", script[0])
 
             # execute script for title matches
-            titleSearch = StdIOProcess(script[0], [searchTitle.encode(pref['systemEncoding'])], scriptProxy, pref['scriptPath'])
+            titleSearch = StdIOProcess(script[0], [searchTitle.encode(pref['systemEncoding'])], scriptProxy, scriptdir)
             execDlg = ScriptExecDialog(titleSearch, modal=True)
 
             # if process was aborted, stop
@@ -568,7 +570,7 @@ class LMCMain(LMCWidgetBase):
                 url = titleMatchDlg.selectedItem()
 
                 # fetch details
-                detailSearch = StdIOProcess(script[0], [url.encode(pref['systemEncoding'])], scriptProxy, pref['scriptPath'])
+                detailSearch = StdIOProcess(script[0], [url.encode(pref['systemEncoding'])], scriptProxy, scriptdir)
                 execDlg2 = ScriptExecDialog(detailSearch, modal=True)
                 
                 # if process was aborted, stop
@@ -843,6 +845,8 @@ app = QApplication(sys.argv)
 QObject.connect(app, SIGNAL("lastWindowClosed()"), app, SLOT("quit()"))
 
 main = LMCMain()
+main.setCaption(defaultCaption)
+
 app.setMainWidget(main)
 main.show()
 app.exec_loop()
